@@ -592,6 +592,21 @@ Optional REGEXP has the meaning documented in the function
   "Regexp for `show-font-get-installed-font-families'.
 Only `let' bind this while calling `show-font-tabulated-mode'.")
 
+(defun show-font-tabulated-select-preview ()
+  "Preview the font on the current line in `show-font-tabulated-mode'."
+  (interactive nil 'show-font-tabulated-mode)
+  (unless (derived-mode-p 'show-font-tabulated-mode)
+    (user-error "Can only do this inside the `show-font-tabulated-mode'"))
+  (if-let* ((family (tabulated-list-get-id)))
+      (show-font-select-preview family)
+    (error "No font family on the current line")))
+
+(defvar show-font-tabulated-mode-map
+  (let ((map (make-sparse-keymap)))
+    (define-key map (kbd "RET") #'show-font-tabulated-select-preview)
+    map)
+  "Key map for the `show-font-tabulated-mode'.")
+
 (define-derived-mode show-font-tabulated-mode tabulated-list-mode "Show fonts"
   "Major mode to display font previews."
   :interactive nil
